# Git commit
%global commit ca156fb9392a02be65e5835306ee4fcd5bc69412
%global shortcommit %(c=%{commit}; echo ${c:0:7})
# Commit count on github
%global svnrev 1873

# Run tests by default: add flag to enable building without running tests.
%bcond_without tests

# RHEL5 version of HDF5 is too old.
%global hdf5ver 1.8.17
# Version of bundled Armadillo
%global armaver 7.500.2
# Use bundled armadillo?
%global armabundle 1

%if 0%{?rhel} == 5
#%global hdf5bundle 1
%global hdf5bundle 0
%else
%global hdf5bundle 0
%endif

Name:		erkale
Version:	0.9
Release:	2.%{svnrev}.%{shortcommit}git%{?dist}
Summary:	A program used to solve the electronic structure of atoms and molecules
Group:		Applications/Engineering
License:	GPLv2+
URL:		http://github.com/susilehtola/erkale/
Source0:	https://github.com/susilehtola/erkale/archive/%{commit}/erkale-%{commit}.tar.gz

# Disable 2GB memory limit in eritable
Patch1:		erkale-eritable.patch

# Bundled libraries, if necessary
Source1:	http://sourceforge.net/projects/arma/files/armadillo-%{armaver}.tar.xz
Source2:	http://www.hdfgroup.org/ftp/HDF5/current/src/hdf5-%{hdf5ver}.tar.bz2

BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%if 0%{?rhel} == 5
BuildRequires:	gcc44
BuildRequires:	gcc44-c++
BuildRequires:	gcc44-gfortran
%else
BuildRequires:	gcc-gfortran
%endif

BuildRequires:	atlas-devel
BuildRequires:	gsl-devel >= 1.4.0
BuildRequires:	zlib-devel

BuildRequires:	libint-devel
BuildRequires:	libxc-devel
BuildRequires:	cmake

# For building documentation
BuildRequires:	doxygen
BuildRequires:	tetex-latex

# Dummy package.
Requires:	erkale-openmp = %{version}-%{release}
Requires:	erkale-serial = %{version}-%{release}

%if !%{armabundle}
BuildRequires:	armadillo-devel
%endif

%if !%{hdf5bundle}
#BuildRequires:	hdf5-devel >= 1.8.0
BuildRequires:	hdf5-devel
%endif

%description
ERKALE is a quantum chemistry program used to solve the electronic structure
of atoms, molecules and molecular clusters. Its specialty is the computation
of x-ray properties, such as electron momentum densities, Compton profiles,
and core and valence electron excitation spectra.
%if %{armabundle}
This package has been compiled with Armadillo %{armaver}.
%endif
%if %{hdf5bundle}
This package has been compiled against HDF5 %{hdf5ver}.
%endif

%package basis
Summary:	Commonly used basis sets for ERKALE
Group:		Applications/Engineering
%if 0%{?rhel} > 5 || 0%{?fedora} > 11
BuildArch:	noarch
%endif

%description basis
This package contains commonly used basis sets for ERKALE.


%package doc
Summary:	Developer documentation for ERKALE
Group:		Documentation
%if 0%{?rhel} > 5 || 0%{?fedora} > 11
BuildArch:	noarch
%endif

%description doc
This package contains developer documentation for ERKALE.


%package devel
Summary:	Development headers and libraries for ERKALE
Group:		Development/Languages
Requires:	erkale-openmp-devel = %{version}-%{release}
Requires:	erkale-serial-devel = %{version}-%{release}

%description devel
This package contains development headers and libraries for ERKALE.


%package serial
Summary:	Serial version of ERKALE
Group:		Applications/Engineering
Requires:	erkale-basis = %{version}-%{release}
# In case the API or ABI breaks
Requires:	erkale-serial-libs = %{version}-%{release}

%description serial
This package contains the serial binaries of ERKALE.


%package serial-libs
Summary:	Serial shared libraries for ERKALE
Group:		System Environment/Libraries
Obsoletes:      erkale-libs < %{version}-%{release}
%if 0%{?fedora} >= 21
Requires:       libint(api)%{?_isa} = %{_libint_apiversion}
%else
Requires:       libint%{?_isa} = %{_libint_version}
%endif
%if !%{hdf5bundle}
Requires:       hdf5%{?_isa} = %{_hdf5_version}
%endif

%description serial-libs 
This package contains the serial shared libraries for ERKALE.


%package serial-devel
Summary:	Development libraries for serial ERKALE
Group:		Development/Languages
Requires:	erkale-devel = %{version}-%{release}
Requires:	erkale-serial-libs = %{version}-%{release}

%description serial-devel
This package contains the serial development library for ERKALE.


%package openmp
Summary:	OpenMP parallellized version of ERKALE
Group:		Applications/Engineering
Requires:	erkale-basis = %{version}-%{release}
# In case the API or ABI breaks
Requires:	erkale-openmp-libs = %{version}-%{release}

%description openmp
This package contains the OpenMP parallellized binaries of ERKALE.


%package openmp-libs
Summary:	OpenMP parallellized shared libraries for ERKALE
Group:		System Environment/Libraries
%if 0%{?fedora} >= 21
Requires:       libint(api)%{?_isa} = %{_libint_apiversion}
%else
Requires:       libint%{?_isa} = %{_libint_version}
%endif
%if !%{hdf5bundle}
Requires:       hdf5%{?_isa} = %{_hdf5_version}
%endif

%description openmp-libs 
This package contains the OpenMP parallellized shared libraries for ERKALE.


%package openmp-devel
Summary:	Development libraries for OpenMP parallellized ERKALE
Group:		Development/Languages
Requires:	erkale-devel = %{version}-%{release}
Requires:	erkale-openmp-libs = %{version}-%{release}

%description openmp-devel
This package contains the OpenMP parallellized development library for ERKALE.


%prep
%setup -q -n %{name}-%{commit}

# Disable memory limit
%patch1 -p1 -b .eritable

# Create version header
cat > src/version.h <<EOF
#ifndef ERKALE_VERSION
#define SVNREVISION "%{svnrev}"
#define GITVERSION "%{commit}"
#define GITSHORT "%{shortcommit}"
#endif
EOF

%if %{armabundle}
# Uncompress Armadillo
tar Jxf %{SOURCE1}
cd armadillo-%{armaver}
export armadir=`pwd`
cd ..
# Generate configuration
echo "set(ARMADILLO_INCLUDE_DIRS \"${armadir}/include\")" > cmake/FindArmadillo.cmake
%else
# Use system armadillo
echo "set(ARMADILLO_INCLUDE_DIRS \"/usr/include\")" > cmake/ArmadilloConfig.cmake
%endif
echo "set(ARMADILLO_FOUND 1)" >> config/ArmadilloConfig.cmake

%if %{hdf5bundle}
# Uncompress HDF5
tar jxf %{SOURCE2}

# Generate configuration
curdir=`pwd`
echo "set(HDF5_INCLUDE_DIRS \"${curdir}/hdf5/include\")" > cmake/FindHDF5.cmake
echo "set(HDF5_LIBRARIES ${curdir}/hdf5/lib/libhdf5.a -lz -ldl)" >> cmake/FindHDF5.cmake
%else
echo "set(HDF5_INCLUDE_DIRS \"%{_includedir}\")" > cmake/FindHDF5.cmake
echo "set(HDF5_LIBRARIES -lhdf5 -lz -lm)" >> cmake/FindHDF5.cmake
%endif

# Get rid of svn files
find . -name \*.svn |xargs rm -rf {} \;

# Disable tests of functionals that are too new
sed -i '/B97/d;/B97/d;/b97/d' tests/TestList.txt

%build
%if 0%{?rhel} == 5
export CC=gcc44
export CXX=g++44
export FC=gfortran44
export F77=gfortran44
%else
export CC=gcc
export CXX=g++
export FC=gfortran
export F77=gfortran
%endif

export CFLAGS="%{optflags} -fPIC"
# Turn off use of Armadillo wrapper
export CXXFLAGS="%{optflags} -fPIC"


# Compile HDF5 if necessary.
%if %{hdf5bundle}
topdir=`pwd`
export FCFLAGS="%{optflags} -fPIC -I%{_fmoddir}"
export FFFLAGS="%{optflags} -fPIC -I%{_fmoddir}"
cd hdf5-%{hdf5ver}
./configure --enable-static --disable-shared --prefix=${topdir}/hdf5 --exec-prefix=${topdir}/hdf5
make %{?_smp_mflags} VERBOSE=1
make install
cd ..
%endif

# Serial version
mkdir serial-%{_target_platform}
cd serial-%{_target_platform}
FC=${FC} %{cmake} .. -DUSE_OPENMP=OFF -DSVN_VERSION=ON \
%if 0%{?fedora} > 20 || 0%{?rhel} > 6
 -DLAPACK_LIBRARIES="-L%{_libdir}/atlas -lsatlas" \
 -DBLAS_LIBRARIES="-L%{_libdir}/atlas -lsatlas"
%else
 -DLAPACK_LIBRARIES="-L%{_libdir}/atlas -llapack -lf77blas -lcblas -latlas" \
 -DBLAS_LIBRARIES="-L%{_libdir}/atlas -lf77blas -lcblas -latlas"
%endif
make %{?_smp_mflags}
cd ..

# Parallel version
mkdir parallel-%{_target_platform}
cd parallel-%{_target_platform}
FC=${FC} %{cmake} .. -DUSE_OPENMP=ON -DSVN_VERSION=ON \
%if 0%{?fedora} > 20 || 0%{?rhel} > 6
 -DLAPACK_LIBRARIES="-L%{_libdir}/atlas -lsatlas" \
 -DBLAS_LIBRARIES="-L%{_libdir}/atlas -lsatlas"
%else
 -DLAPACK_LIBRARIES="-L%{_libdir}/atlas -llapack -lf77blas -lcblas -latlas" \
 -DBLAS_LIBRARIES="-L%{_libdir}/atlas -lf77blas -lcblas -latlas"
%endif
make %{?_smp_mflags}
cd ..

# Build documentation
doxygen


%install
rm -rf %{buildroot}

# Parallel version
cd parallel-%{_target_platform}
make install DESTDIR=%{buildroot}
cd ..
# Serial version
cd serial-%{_target_platform}
make install DESTDIR=%{buildroot}
cd ..
# Install basis sets
mkdir -p %{buildroot}%{_datadir}/%{name}/
cp -a basis %{buildroot}%{_datadir}/%{name}/

# Install examples
cp -a examples %{buildroot}%{_datadir}/%{name}/

%check
%if %{without tests}
echo "RPM built without running tests."
%else
# Run tests
echo "Serial tests"
make -C serial-%{_target_platform} test || :
echo "Parallel tests"
make -C parallel-%{_target_platform} test || :
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)

%files serial
%defattr(-,root,root,-)
%{_bindir}/erkale
%{_bindir}/erkale_adf_emd
%{_bindir}/erkale_bastool
%{_bindir}/erkale_casida
%{_bindir}/erkale_copt
%{_bindir}/erkale_copt_plateau
%{_bindir}/erkale_cube
%{_bindir}/erkale_emd
%{_bindir}/erkale_fchkpt
%{_bindir}/erkale_geom
%{_bindir}/erkale_loc
%{_bindir}/erkale_pop
%{_bindir}/erkale_slaterfit
%{_bindir}/erkale_xrs

%files basis
%defattr(-,root,root,-)
%{_datadir}/erkale/

%files doc
%defattr(-,root,root,-)
%doc doc/html/*

%files devel
%defattr(-,root,root,-)
%{_includedir}/erkale/

%files serial-devel
%defattr(-,root,root,-)
%{_libdir}/liberkale.so
%{_libdir}/liberkale_cmp.so
%{_libdir}/liberkale_emd.so
%{_libdir}/liberkale_xrs.so

%files serial-libs
%defattr(-,root,root,-)
%doc AUTHORS CITATION COPYING INSTALL TODO
%{_libdir}/liberkale.so.*
%{_libdir}/liberkale_cmp.so.*
%{_libdir}/liberkale_emd.so.*
%{_libdir}/liberkale_xrs.so.*

%files openmp
%defattr(-,root,root,-)
%{_bindir}/erkale_omp
%{_bindir}/erkale_adf_emd_omp
%{_bindir}/erkale_casida_omp
%{_bindir}/erkale_copt_omp
%{_bindir}/erkale_copt_plateau_omp
%{_bindir}/erkale_cube_omp
%{_bindir}/erkale_emd_omp
%{_bindir}/erkale_fchkpt_omp
%{_bindir}/erkale_geom_omp
%{_bindir}/erkale_loc_omp
%{_bindir}/erkale_pop_omp
%{_bindir}/erkale_slaterfit_omp
%{_bindir}/erkale_xrs_omp

%files openmp-devel
%defattr(-,root,root,-)
%{_libdir}/liberkale_omp.so
%{_libdir}/liberkale_cmp_omp.so
%{_libdir}/liberkale_emd_omp.so
%{_libdir}/liberkale_xrs_omp.so

%files openmp-libs
%defattr(-,root,root,-)
%doc AUTHORS CITATION COPYING INSTALL TODO
%{_libdir}/liberkale_omp.so.*
%{_libdir}/liberkale_cmp_omp.so.*
%{_libdir}/liberkale_emd_omp.so.*
%{_libdir}/liberkale_xrs_omp.so.*

%post serial-libs -p /sbin/ldconfig
%postun serial-libs -p /sbin/ldconfig
%post openmp-libs -p /sbin/ldconfig
%postun openmp-libs -p /sbin/ldconfig

%changelog
* Sat Nov 26 2016 Susi Lehtola <jussilehtola@fedoraproject.org> - 0.9-2.1873.ca156fb9git
- Update to newest snapshot.

* Sat Jul 09 2016 Susi Lehtola <jussilehtola@fedoraproject.org> - 0.9-2.1842.02e36b11git
- Update to newest snapshot.

* Mon Apr 04 2016 Susi Lehtola <jussilehtola@fedoraproject.org> - 0.9-2.1772.5e0c55c1git
- Update to newest snapshot.

* Sun Nov 08 2015 Susi Lehtola <jussilehtola@fedoraproject.org> - 0.9-1.1737.65f42e77git
- Switch to using copr for builds.



